<?php

/**
 * @file
 * Hooks specific to the SitesGroup module.
 *
 * @todo Think about moving this to the main module?
 */

use Drupal\Core\Entity\ContentEntityInterface;
use Drupal\group\Entity\GroupTypeInterface;

/**
 * @addtogroup hooks
 * @{
 */

/**
 * Alter the field_mapping of the sites_group group_type configuration.
 *
 * @param array $field_mappings
 *   A list select form elements which can be mapped to fields on the group
 *   type.
 * @param \Drupal\group\Entity\GroupTypeInterface $group_type
 *   The group_type to alter the field mappings for.
 *
 * @see \Drupal\sites_group\FormDecorator\ParagraphTypeEditFormAlter
 */
function hook_sites_group_field_mappings_alter(array &$field_mappings, GroupTypeInterface $group_type) {
  if ($group_type->id() == 'microsite') {
    $field_mappings['prefix'] = [
      '#title' => t('The microsite prefix'),
      '#description' => t('The prefix of the microsite in case the hostname is not unique.'),
      '#required' => FALSE,
    ];
  }
}

/**
 * Alter the default_settings of the sites_group group_type configuration.
 *
 * @param array $default_settings
 *   A list of form elements keyed by setting.
 * @param \Drupal\group\Entity\GroupTypeInterface $group_type
 *   The group_type to alter the field mappings for.
 *
 * @see \Drupal\sites_group\FormDecorator\ParagraphTypeEditFormAlter
 */
function hook_sites_group_default_settings_alter(array &$default_settings, GroupTypeInterface $group_type) {
  if ($group_type->id() == 'microsite') {
    $default_settings['prefix'] = [
      '#title' => t('The default prefix'),
      '#type' => 'textfield',
      '#default_value' => 'olivero',
    ];
  }
}

/**
 * Alter the apply_to_non_overideable_entities configuration.
 *
 * @param bool $apply
 *   Indicates weather we want to apply the override settings.
 * @param \Drupal\Core\Entity\ContentEntityInterface $entity
 *   The entity to check for.
 *
 * @see \Drupal\sites_group\FormDecorator\EntityOverrideAbilityClues
 */
function hook_sites_group_overrides_non_overideable_entities_alter(bool &$apply, ContentEntityInterface $entity) {
  if ($entity->getEntityTypeId() == 'group_content_menu') {
    $apply = FALSE;
  }
}


/**
 * @} End of "addtogroup hooks".
 */
