<?php

declare(strict_types=1);

namespace Drupal\sites_group\EventSubscriber;

use Drupal\sites\Event\SiteSettings;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
 * Event subscriber to manipulate site settings.
 */
final class SitesGroupSubscriber implements EventSubscriberInterface {

  /**
   * Format languages correctly when coming from language select field.
   *
   * @param \Drupal\sites\Event\SiteSettings $event
   *   The site setting event.
   *
   * @return void
   */
  public function onSiteSetting(SiteSettings $event): void {
    if (
      ($language = $event->getSetting('languages')) &&
      ($selected_language = $event->getSetting('selected_language'))
    ) {
      if (is_array($language)) {
        $languages = array_combine(array_values($language), $language);
        $languages[$selected_language] = '';
        $event->setSetting('languages', $languages);
      } else {
        $event->setSetting('languages', [$language => '']);
      }
    }
  }

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents(): array {
    return [
      SiteSettings::SITES_SITE_SETTINGS => ['onSiteSetting', 0],
    ];
  }

}
