<?php

declare(strict_types=1);

namespace Drupal\Tests\sites_group\Kernel;

use Drupal\group\Entity\Group;
use Drupal\group\Entity\GroupType;
use Drupal\KernelTests\Core\Entity\EntityKernelTestBase;
use Drupal\node\Entity\Node;
use Drupal\node\Entity\NodeType;
use Drupal\user\Entity\User;

/**
 * Tests the SitesGroupService class.
 *
 * @group sites_group
 */
class SitesGroupServiceKernelTest extends EntityKernelTestBase {

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'system',
    'user',
    'node',
    'field',
    'group',
    'sites',
    'sites_group',
    'flexible_permissions',
    'path_alias',
    'sites_path_prefix',
  ];

  /**
   * The sites group service.
   *
   * @var \Drupal\sites_group\SitesGroupServiceInterface
   */
  protected $sitesGroupService;

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();

    $this->installEntitySchema('user');
    $this->installEntitySchema('node');
    $this->installEntitySchema('group');
    $this->installConfig(['group', 'node', 'sites_group']);
    $this->installSchema('node', ['node_access']);
    $this->installSchema('system', ['sequences']);

    NodeType::create(['type' => 'page', 'name' => 'Basic page'])->save();

    $group_type = GroupType::create([
      'id' => 'test_group',
      'label' => 'Test Group',
      'description' => 'Test Group Type',
    ]);
    $group_type->save();

    // Get the node service.
    $this->sitesGroupService = $this->container->get('sites_group.service');
  }

  /**
   * Tests the isContentPluginInstalledForGroup method.
   * If there is no site configured, there should be no group relationship.
   */
  public function testIsContentPluginIsNotInstalledForGroup(): void {
    $user = User::create(['name' => $this->randomString()]);
    $user->save();

    $group = Group::create([
      'type' => 'test_group',
      'label' => 'Test Group',
      'uid' => $user->id(),
    ]);
    $group->save();

    // Create a node.
    $node = Node::create([
      'type' => 'page',
      'title' => 'Test Page',
      'uid' => $user->id(),
    ]);
    $node->save();

    $this->sitesGroupService->ensureSiteContext($node);

    $relationships = $group->getRelationshipsByEntity($node);
    $this->assertEmpty($relationships, 'The node should be not stored in the group.');
  }

}
